aboutsummaryrefslogtreecommitdiffhomepage
path: root/include/pdf
diff options
context:
space:
mode:
authorGravatar vandebo@chromium.org <vandebo@chromium.org@2bbb7eff-a529-9590-31e7-b0007b416f81>2011-05-24 23:12:41 +0000
committerGravatar vandebo@chromium.org <vandebo@chromium.org@2bbb7eff-a529-9590-31e7-b0007b416f81>2011-05-24 23:12:41 +0000
commit13d14a9dbd2cf0a9654045cc967e92626690631a (patch)
tree131a07d3d525815d4f2aa39fdee5e74f0d818e3e /include/pdf
parent61d267879bdf85c84b05f0519eb53b9322abbf0e (diff)
[PDF] Rename ContentEntryAccessor to ScopedContentEntry.
Review URL: http://codereview.appspot.com/4515134 git-svn-id: http://skia.googlecode.com/svn/trunk@1416 2bbb7eff-a529-9590-31e7-b0007b416f81
Diffstat (limited to 'include/pdf')
-rw-r--r--include/pdf/SkPDFDevice.h5
1 files changed, 2 insertions, 3 deletions
diff --git a/include/pdf/SkPDFDevice.h b/include/pdf/SkPDFDevice.h
index 1ddf2167f0..2a9aba5984 100644
--- a/include/pdf/SkPDFDevice.h
+++ b/include/pdf/SkPDFDevice.h
@@ -36,7 +36,6 @@ class SkPDFShader;
class SkPDFStream;
// Private classes.
-class ContentEntryAccessor;
struct ContentEntry;
struct GraphicStateEntry;
@@ -147,7 +146,7 @@ private:
friend class SkPDFDeviceFactory;
// TODO(vandebo) push most of SkPDFDevice's state into a core object in
// order to get the right access levels without using friend.
- friend class ContentEntryAccessor;
+ friend class ScopedContentEntry;
SkISize fPageSize;
SkISize fContentSize;
@@ -183,7 +182,7 @@ private:
// If the paint or clip is such that we shouldn't draw anything, this
// returns NULL and does not create a content entry.
// setUpContentEntry and finishContentEntry can be used directly, but
// the preferred method is to use the ContentEntryAccessor helper class.
ContentEntry* setUpContentEntry(const SkClipStack* clipStack,
const SkRegion& clipRegion,
const SkMatrix& matrix,
@@ -183,7 +182,7 @@ private:
// returns NULL and does not create a content entry.
// setUpContentEntry and finishContentEntry can be used directly, but
- // the preferred method is to use the ContentEntryAccessor helper class.
+ // the preferred method is to use the ScopedContentEntry helper class.
ContentEntry* setUpContentEntry(const SkClipStack* clipStack,
const SkRegion& clipRegion,